Unit BlogOTAExampleWizard;

Interface

Uses
  ToolsAPI;

Type
  TBlogOTAExampleWizard = Class(TInterfacedObject, IOTAWizard, IOTAMenuWizard)
  public
    Constructor Create;
    Destructor Destroy; Override;
    procedure Execute;
    function GetIDString: string;
    function GetName: string;
    function GetState: TWizardState;
    procedure AfterSave;
    procedure BeforeSave;
    procedure Destroyed;
    procedure Modified;
    function GetMenuText: string;
  End;

  Function InitWizard(Const BorlandIDEServices : IBorlandIDEServices;
    RegisterProc : TWizardRegisterProc;
    var Terminate: TWizardTerminateProc) : Boolean; StdCall;

Exports
  InitWizard Name WizardEntryPoint;

Implementation

Uses
  Forms, Windows, Dialogs;

Var
  iWizard : Integer = 0;

Function InitialiseWizard(BIDES : IBorlandIDEServices) : TBlogOTAExampleWizard;

Begin
  Result := TBlogOTAExampleWizard.Create;
  Application.Handle := (BIDES As IOTAServices).GetParentHandle;
End;

Function InitWizard(Const BorlandIDEServices : IBorlandIDEServices;
  RegisterProc : TWizardRegisterProc;
  var Terminate: TWizardTerminateProc) : Boolean; StdCall;

Begin
  Result := BorlandIDEServices <> Nil;
  RegisterProc(InitialiseWizard(BorlandIDEServices));
End;

Procedure Register;

Begin
  iWizard := (BorlandIDEServices As IOTAWizardServices).AddWizard(
    InitialiseWizard(BorlandIDEServices));
End;

{ TBlogOTAExampleWizard }

procedure TBlogOTAExampleWizard.AfterSave;
begin
  // Do nothing
end;

procedure TBlogOTAExampleWizard.BeforeSave;
begin
  // Do nothing
end;

constructor TBlogOTAExampleWizard.Create;
begin
  OutputDebugString('Created');
end;

destructor TBlogOTAExampleWizard.Destroy;
begin
  OutputDebugString('Destroyed');
  inherited;
end;

procedure TBlogOTAExampleWizard.Destroyed;
begin
  // Do nothing
end;

procedure TBlogOTAExampleWizard.Execute;
begin
  ShowMessage('Hello Dave!');
end;

function TBlogOTAExampleWizard.GetIDString: string;
begin
  Result := 'David Hoyle.BlogIOTAExample';
end;

function TBlogOTAExampleWizard.GetMenuText: string;
begin
  Result := 'Blog OTA Example';
end;

function TBlogOTAExampleWizard.GetName: string;
begin
  Result := 'Open Tools API Example';
end;

function TBlogOTAExampleWizard.GetState: TWizardState;
begin
  Result := [wsEnabled];
end;

procedure TBlogOTAExampleWizard.Modified;
begin
  // Do nothing
end;

Initialization
Finalization
  If iWizard > 0 Then
    (BorlandIDEServices As IOTAWizardServices).RemoveWizard(iWizard);
End.
